<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ru">
<context>
    <name>LxImage::Application</name>
    <message>
        <location filename="../../application.cpp" line="94"/>
        <source>Take a screenshot</source>
        <translation>Сделать снимок экрана</translation>
    </message>
    <message>
        <location filename="../../application.cpp" line="98"/>
        <source>[FILE1, FILE2,...]</source>
        <translation>[ФАЙЛ1, ФАЙЛ2, ...]</translation>
    </message>
</context>
<context>
    <name>LxImage::ImageShackUpload</name>
    <message>
        <location filename="../../upload/imageshackupload.cpp" line="49"/>
        <source>unknown error response</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>LxImage::ImgurUpload</name>
    <message>
        <location filename="../../upload/imgurupload.cpp" line="46"/>
        <source>unknown error response</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>LxImage::MainWindow</name>
    <message>
        <location filename="../../mainwindow.cpp" line="145"/>
        <source>About</source>
        <translation>О программе</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="146"/>
        <source>LXImage - a simple and fast image viewer

Copyright (C) 2013
LXQt Project: https://lxqt.org/

Authors:
Hong Jen Yee (PCMan) &lt;pcman.tw@gmail.com&gt;</source>
        <translation>LXImage - простой и быстрый просмотрщик изображений

Copyright (C) 2013
LXQt Project: https://lxqt.org/

Authors:
Hong Jen Yee (PCMan) &lt;pcman.tw@gmail.com&gt;</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="255"/>
        <source>Open File</source>
        <translation>Открыть файл</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="256"/>
        <location filename="../../mainwindow.cpp" line="283"/>
        <source>Image files (%1)</source>
        <translation>Файлы изображений (%1)</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="262"/>
        <source>Open directory</source>
        <translation>Открыть папку</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="283"/>
        <source>Save File</source>
        <translation>Сохранить файл</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="539"/>
        <source>[*]%1 (Loading...) - Image Viewer</source>
        <translation>[*]%1 (Загружается...) - Просмотрщик изображений</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="544"/>
        <source>[*]%1 (Failed to Load) - Image Viewer</source>
        <translation>[*]%1 (Ошибка загрузки) - Просмотрщик изображений</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="548"/>
        <source>[*]%1 (%2x%3) - Image Viewer</source>
        <translation>[*]%1 (%2x%3) - Просмотрщик изображений</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="584"/>
        <source>[*]Image Viewer</source>
        <translation>[*]Просмотрщик изображений</translation>
    </message>
    <message>
        <source>%1 (Loading...) - Image Viewer</source>
        <translation type="vanished">%1 (Загружается...) - Просмотрщик изображений</translation>
    </message>
    <message>
        <source>%1 (Failed to Load) - Image Viewer</source>
        <translation type="vanished">%1 (Ошибка загрузки) - Просмотрщик изображений</translation>
    </message>
    <message>
        <source>%1 (%2x%3) - Image Viewer</source>
        <translation type="vanished">%1 (%2x%3) - Просмотрщик изображений</translation>
    </message>
    <message>
        <source>Image Viewer</source>
        <translation type="vanished">Просмотрщик изображений</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="851"/>
        <source>Thumbnails</source>
        <translation>Эскизы</translation>
    </message>
</context>
<context>
    <name>LxImage::UploadDialog</name>
    <message>
        <location filename="../../upload/uploaddialog.cpp" line="47"/>
        <source>Imgur</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../upload/uploaddialog.cpp" line="48"/>
        <source>ImageShack</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../upload/uploaddialog.cpp" line="124"/>
        <source>Start</source>
        <translation>Запустить</translation>
    </message>
    <message>
        <location filename="../../upload/uploaddialog.cpp" line="127"/>
        <source>Stop</source>
        <translation>Остановить</translation>
    </message>
    <message>
        <location filename="../../upload/uploaddialog.cpp" line="130"/>
        <source>Close</source>
        <translation>Закрыть</translation>
    </message>
    <message>
        <location filename="../../upload/uploaddialog.cpp" line="137"/>
        <source>Error</source>
        <translation>Ошибка</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../../mainwindow.ui" line="14"/>
        <source>Image Viewer</source>
        <translation>Просмотрщик изображений</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="162"/>
        <source>&amp;About</source>
        <translation>О &amp;программе</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="172"/>
        <source>&amp;Open File</source>
        <translation>&amp;Открыть файл</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="175"/>
        <source>Ctrl+O</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="185"/>
        <source>&amp;Save</source>
        <translation>&amp;Сохранить</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="188"/>
        <source>Ctrl+S</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="198"/>
        <source>Save &amp;As</source>
        <translation>Сохранить &amp;как</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="201"/>
        <source>Ctrl+A</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="211"/>
        <source>&amp;Close</source>
        <translation>&amp;Закрыть</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="214"/>
        <source>Ctrl+W</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="224"/>
        <source>Zoom &amp;In</source>
        <translation>При&amp;близить</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="237"/>
        <source>Zoom &amp;Out</source>
        <translation>От&amp;далить</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="240"/>
        <source>Ctrl+-</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="250"/>
        <source>&amp;Copy to Clipboard</source>
        <translation>Скопировать в &amp;буфер обмена</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="260"/>
        <location filename="../../mainwindow.ui" line="263"/>
        <source>Next File</source>
        <translation>Следующий файл</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="276"/>
        <location filename="../../mainwindow.ui" line="279"/>
        <source>Previous File</source>
        <translation>Предыдущий файл</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="266"/>
        <source>PgDown</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="227"/>
        <source>Ctrl+=</source>
        <translation>Ctrl+=</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="282"/>
        <source>PgUp</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="292"/>
        <source>Original Size</source>
        <translation>Исходный размер</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="295"/>
        <source>Ctrl+0</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="305"/>
        <source>&amp;Fit</source>
        <translation>&amp;Заполнить</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="315"/>
        <source>&amp;Rotate Clockwise</source>
        <translation>Пове&amp;рнуть по часовой стрелке</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="325"/>
        <source>Rotate &amp;Counterclockwise</source>
        <translation>Повернуть &amp;против часовой стрелки</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="330"/>
        <source>P&amp;references</source>
        <translation>&amp;Настройки</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="335"/>
        <source>&amp;Print</source>
        <translation>&amp;Печать</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="338"/>
        <source>Ctrl+P</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="348"/>
        <source>First File</source>
        <translation>Первый файл</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="351"/>
        <source>Home</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="361"/>
        <source>Last File</source>
        <translation>Последний файл</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="364"/>
        <source>End</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="374"/>
        <source>&amp;New Window</source>
        <translation>Новое &amp;окно</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="377"/>
        <source>Ctrl+N</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="382"/>
        <source>Flip &amp;Horizontally</source>
        <translation>Отразить &amp;горизонтально</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="392"/>
        <source>Capture Screenshot</source>
        <translation>Сделать снимок экрана</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="400"/>
        <source>F&amp;ull Screen</source>
        <translation>Полный &amp;экран</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="403"/>
        <source>F11</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="408"/>
        <source>Flip &amp;Vertically</source>
        <translation>Отразить &amp;вертикально</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="418"/>
        <source>&amp;Paste from Clipboard</source>
        <translation>&amp;Вставить из буфера обмена</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="431"/>
        <source>&amp;Slide Show</source>
        <translation>&amp;Слайд-шоу</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="441"/>
        <source>&amp;Delete</source>
        <translation>&amp;Удалить</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="444"/>
        <source>Del</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="452"/>
        <source>Show Thumbnails</source>
        <translation>Показать эскизы</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="457"/>
        <source>File Properties</source>
        <translation>Свойства файла</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="465"/>
        <source>Open &amp;Directory</source>
        <translation>Открыть &amp;папку</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="468"/>
        <source>Ctrl+D</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="476"/>
        <source>Upload</source>
        <translation>Загрузить</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="479"/>
        <source>Upload the image</source>
        <translation>Загрузить изображение</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="55"/>
        <source>&amp;File</source>
        <translation>&amp;Файл</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="72"/>
        <source>&amp;Help</source>
        <translation>&amp;Помощь</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="78"/>
        <source>Go</source>
        <translation>Перейти</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="87"/>
        <source>&amp;View</source>
        <translation>&amp;Вид</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="101"/>
        <source>&amp;Edit</source>
        <translation>&amp;Редактировать</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="123"/>
        <source>Toolbar</source>
        <translation>Панель инструментов</translation>
    </message>
</context>
<context>
    <name>PreferencesDialog</name>
    <message>
        <location filename="../../preferencesdialog.ui" line="14"/>
        <source>Preferences</source>
        <translation>Настройки</translation>
    </message>
    <message>
        <location filename="../../preferencesdialog.ui" line="33"/>
        <source>Icon theme:</source>
        <translation>Тема значков:</translation>
    </message>
    <message>
        <location filename="../../preferencesdialog.ui" line="43"/>
        <source>Normal background color:</source>
        <translation>Обычный цвет фона:</translation>
    </message>
    <message>
        <location filename="../../preferencesdialog.ui" line="50"/>
        <source>Fullscreen background color:</source>
        <translation>Цвет фона для режима полного экрана:</translation>
    </message>
    <message>
        <location filename="../../preferencesdialog.ui" line="71"/>
        <source>Slide show interval (seconds):</source>
        <translation>Интервал слайд-шоу (в секундах):</translation>
    </message>
    <message>
        <location filename="../../preferencesdialog.ui" line="24"/>
        <source>General</source>
        <translation>Общие</translation>
    </message>
</context>
<context>
    <name>ScreenshotDialog</name>
    <message>
        <location filename="../../screenshotdialog.ui" line="14"/>
        <source>Screenshot</source>
        <translation>Снимок экрана</translation>
    </message>
    <message>
        <location filename="../../screenshotdialog.ui" line="27"/>
        <source>Take a screenshot</source>
        <translation>Сделать снимок экрана</translation>
    </message>
    <message>
        <location filename="../../screenshotdialog.ui" line="34"/>
        <source>Region</source>
        <translation>Область</translation>
    </message>
    <message>
        <location filename="../../screenshotdialog.ui" line="40"/>
        <source>Whole screen</source>
        <translation>Весь экран</translation>
    </message>
    <message>
        <location filename="../../screenshotdialog.ui" line="50"/>
        <source>Current window only</source>
        <translation>Только активное окно</translation>
    </message>
    <message>
        <location filename="../../screenshotdialog.ui" line="57"/>
        <source>Capture an area of the screen</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../screenshotdialog.ui" line="67"/>
        <source>Include mouse cursor</source>
        <translation>Показывать курсор мыши</translation>
    </message>
    <message>
        <location filename="../../screenshotdialog.ui" line="74"/>
        <source> seconds</source>
        <translation> секунд(ы)</translation>
    </message>
    <message>
        <location filename="../../screenshotdialog.ui" line="91"/>
        <source>Delay:</source>
        <translation>Задержка:</translation>
    </message>
    <message>
        <location filename="../../screenshotdialog.ui" line="101"/>
        <source>Include window title and frame</source>
        <translation>Показывать заголовок и обрамление окна</translation>
    </message>
</context>
<context>
    <name>UploadDialog</name>
    <message>
        <location filename="../../upload/uploaddialog.ui" line="14"/>
        <source>Upload</source>
        <translation type="unfinished">Загрузить</translation>
    </message>
</context>
</TS>
